
clearvars           % clear previous data

% --------------  Simulation Settings -------------------------------------

g = 9.81;           % gravitational acceleration (m/sec^2)
RPM = 30/pi;        % convert rad/sec to rpm
MPH = 2.236936;     % convert m/sec to mph
DEG = 180/pi;       % convert rad to deg
RAD = pi/180;       % convert deg to rad
tstep = .001;       % simulation time step
dec = 1;            % save data decimation (for example, dec = 10 means only every 10th data point is saved)

% --------------  Vehicle Parameters --------------------------------------

m = 9525.4404;      % vehicle mass (kg)
hv = 2.20726;       % vehicle height (m)
wv = 2.4003;        % vehicle width (m)
lv = 5.40512;       % vehicle length (m)

l1 = 0;             % distance from axle 1 to axle 1 (m)
l2 = 4.0721;        % distance from axle 1 to axle 2 (m)
la = 2.3;           % distance from first axle to vehicle CG (m)
ha = 1.311;         % vehicle CG height (m)
hw = 1.10363;       % drag force height (m)

Wa = m*g;           % vehicle weight (N)
Ia = m*(la)^2;      % moment of inertia (kgm^2)
deltaa = 1.1;       % rotational inertia factor (unitless)
rhoa = 1.225;       % air density (kg/m^3)
cx = 0.75;          % vehicle's drag coefficient (unitless)
Af = 0.8*wv*hv;     % vehicle's frontal area projection (m^2)

ud = 1;             % axle open differential gear ratio
u1 = 4.3;           % final drive gear ratio: front
u2 = 4.3;           % final drive gear ratio: rear

m1 = m*(1-la/l2);   % front mass (kg)
ms1 = m1*.875*.5;   % front corner sprung mass (kg)
mu1 = m1*.125*.5;   % front corner unsprung mass (kg)
Ww1 = (ms1+mu1)*g;  % front corner weight (N)

m2 = m*(la/l2);     % rear mass (kg)
ms2 = m2*.875*.5;   % rear corner sprung mass (kg)
mu2 = m2*.125*.5;   % rear corner unsprung mass (kg)
Ww2 = (ms2+mu2)*g;  % rear corner weight (N)

Kt = 96130;         % tire tangential stiffness: front (N/m)
Ks = 100E3/2;       % suspension stiffness: front (N/m)
Ct = 1740;          % tire damping
Cs = 13000;         % suspension damping
Calpha = 867*DEG;   % cornering stiffness

% --------------  Tire Parameters -----------------------------------------

r1 = 0.546;         % unloaded tire radius: front (m)
pw1 = 0.12E6;       % tire internal pressure: front (Pa)
tb1 = wv-.365;      % distance between left and right tires: front (m)
hy = r1;            % height of lateral centrifugal force (m)
nu11 = 0.1;         % tire parameter nu1: front (1/m)
nu21 = 0.2;         % tire parameter nu2: rear (1/m)

%using same tires at front and rear
r2 = r1;            % unloaded tire radius: rear (m)
pw2 = pw1;          % tire internal pressure: rear (Pa)
nu12 = nu11;        % tire parameter nu1: rear (1/m)
nu22 = nu21;        % tire parameter nu2: rear (1/m)
tb2 = tb1;          % distance between left and right tires: rear (m)


% ------------ Hybrid Powertrain Parameters -----------------------------

efft = 0.97;        % transmission efficiency
um = 1.3;           % motor gear ratio
ug = 1;             % engine/generator gear ratio
effreg = 0.6;       % regenerative braking efficiency

SOC0 = .80;         % battery initial state of charge (unitless)
Qt = 40;            % battery storage capacity (A-hr)
ibc = 150;          % battery max charge amps
ibd = 200;          % battery max discharge amps
effbatd = 0.9;      % battery discharge efficiency
effbatc = 0.9;      % battery charge efficiency

In = 1;     %engine inertia
Bn = 0;     %engine damping coefficient

SOCStart = 0.6;     % state of charge to begin charging at
SOCStop = 0.8;      % state of charge to end charging at
KPe =  0.001;       % engine controller proportional gain (unitless)
KIe = 0.01;         % engine controller integral gain (unitless)
KDe = 0;            % engine controller derivative gain (unitless)
emax = 2300;        % engine max speed (rpm)
espeed = 1600;      % engine target speed (rpm)
emin1 = 1200;       % use generator to start engine if RPM < this
emin2 = espeed;     % engine speed when generator stops supporting engine

disp('Variables for vehicle model loaded to workspace')

